summaryrefslogtreecommitdiff
path: root/deps/icu-small/source/i18n/unicode/unumberformatter.h
diff options
context:
space:
mode:
Diffstat (limited to 'deps/icu-small/source/i18n/unicode/unumberformatter.h')
-rw-r--r--deps/icu-small/source/i18n/unicode/unumberformatter.h36
1 files changed, 24 insertions, 12 deletions
diff --git a/deps/icu-small/source/i18n/unicode/unumberformatter.h b/deps/icu-small/source/i18n/unicode/unumberformatter.h
index b37f80c503..d05b15cdec 100644
--- a/deps/icu-small/source/i18n/unicode/unumberformatter.h
+++ b/deps/icu-small/source/i18n/unicode/unumberformatter.h
@@ -91,7 +91,7 @@
* </ul>
*
* <p>
- * This enum is similar to {@link com.ibm.icu.text.MeasureFormat.FormatWidth}.
+ * This enum is similar to {@link UMeasureFormatWidth}.
*
* @draft ICU 60
*/
@@ -190,10 +190,9 @@ typedef enum UNumberUnitWidth {
* Note: This enum specifies the strategy for grouping sizes. To set which character to use as the
* grouping separator, use the "symbols" setter.
*
- * @draft ICU 61 -- TODO: This should be renamed to UNumberGroupingStrategy before promoting to stable,
- * for consistency with the other enums.
+ * @draft ICU 63
*/
-typedef enum UGroupingStrategy {
+typedef enum UNumberGroupingStrategy {
/**
* Do not display grouping separators in any locale.
*
@@ -254,16 +253,28 @@ typedef enum UGroupingStrategy {
*
* @draft ICU 61
*/
- UNUM_GROUPING_THOUSANDS,
+ UNUM_GROUPING_THOUSANDS
+#ifndef U_HIDE_INTERNAL_API
+ ,
/**
* One more than the highest UGroupingStrategy value.
*
* @internal ICU 62: The numeric value may change over time; see ICU ticket #12420.
*/
UNUM_GROUPING_COUNT
+#endif /* U_HIDE_INTERNAL_API */
+
+} UNumberGroupingStrategy;
+
+#ifndef U_HIDE_DEPRECATED_API
+/**
+ * Old name for compatibility: will be removed in ICU 64.
+ * @deprecated ICU 63
+ */
+typedef UNumberGroupingStrategy UGroupingStrategy;
+#endif /* U_HIDE_DEPRECATED_API */
-} UGroupingStrategy;
#endif /* U_HIDE_DRAFT_API */
#ifndef U_HIDE_DRAFT_API
@@ -398,6 +409,8 @@ typedef enum UNumberDecimalSeparatorDisplay {
#endif /* U_HIDE_DRAFT_API */
#ifndef U_HIDE_DRAFT_API
+
+struct UNumberFormatter;
/**
* C-compatible version of icu::number::LocalizedNumberFormatter.
*
@@ -405,10 +418,9 @@ typedef enum UNumberDecimalSeparatorDisplay {
*
* @draft ICU 62
*/
-struct UNumberFormatter;
typedef struct UNumberFormatter UNumberFormatter;
-
+struct UFormattedNumber;
/**
* C-compatible version of icu::number::FormattedNumber.
*
@@ -416,7 +428,6 @@ typedef struct UNumberFormatter UNumberFormatter;
*
* @draft ICU 62
*/
-struct UFormattedNumber;
typedef struct UFormattedNumber UFormattedNumber;
@@ -559,7 +570,8 @@ unumf_resultToString(const UFormattedNumber* uresult, UChar* buffer, int32_t buf
*
* NOTE: All fields of the UFieldPosition must be initialized before calling this method.
*
- * @param fieldPosition
+ * @param uresult The object containing the formatted number.
+ * @param ufpos
* Input+output variable. On input, the "field" property determines which field to look up,
* and the "endIndex" property determines where to begin the search. On output, the
* "beginIndex" field is set to the beginning of the first occurrence of the field after the
@@ -580,7 +592,7 @@ unumf_resultNextFieldPosition(const UFormattedNumber* uresult, UFieldPosition* u
* If you need information on only one field, use unumf_resultNextFieldPosition().
*
* @param uresult The object containing the formatted number.
- * @param fpositer
+ * @param ufpositer
* A pointer to a UFieldPositionIterator created by {@link #ufieldpositer_open}. Iteration
* information already present in the UFieldPositionIterator is deleted, and the iterator is reset
* to apply to the fields in the formatted string created by this function call. The field values
@@ -254,16 +253,28 @@ typedef enum UGroupingStrategy {
/**
- * One more than the highest UGroupingStrategy value.
+ * One more than the highest UNumberGroupingStrategy value.
*
* @internal ICU 62: The numeric value may change over time; see ICU ticket #12420.